@@ -29,6 +29,7 @@ SRR = {
         {"status": "error", "code": 404, "data": {}},
         {"key": "error.404"},
     ),
+    "version_114": ({"data": {"productVersion": "11.4.0-20200721.1338.d3969b3"}}, None),
     "end_of_sequence": (None, "Unexpected call to send_request"),
     "generic_error": (None, "Expected error"),
     "delete_good": ({"code": 204}, None),
@@ -150,8 +151,12 @@ class TestMyModule(unittest.TestCase):
             grid_dns_module()
         print("Info: test_module_fail_when_required_args_missing: %s" % exc.value.args[0]["msg"])
 
-    def test_module_fail_when_required_args_present(self):
+    @patch("ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request")
+    def test_module_fail_when_required_args_present(self, mock_request):
         """required arguments are reported as errors"""
+        mock_request.side_effect = [
+            SRR["version_114"],
+        ]
         with pytest.raises(AnsibleExitJson) as exc:
             set_module_args(self.set_default_args_pass_check())
             grid_dns_module()
@@ -162,12 +167,13 @@ class TestMyModule(unittest.TestCase):
     @patch("ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request")
     def test_set_na_sg_grid_dns_servers_pass(self, mock_request):
         set_module_args(self.set_args_set_na_sg_grid_dns_servers())
-        my_obj = grid_dns_module()
         mock_request.side_effect = [
+            SRR["version_114"],
             SRR["no_dns_servers"],  # get
             SRR["dns_servers"],  # post
             SRR["end_of_sequence"],
         ]
+        my_obj = grid_dns_module()
         with pytest.raises(AnsibleExitJson) as exc:
             my_obj.apply()
         print("Info: test_set_na_sg_grid_dns_servers_pass: %s" % repr(exc.value.args[0]))
@@ -176,11 +182,12 @@ class TestMyModule(unittest.TestCase):
     @patch("ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request")
     def test_idempotent_set_na_sg_grid_dns_servers_pass(self, mock_request):
         set_module_args(self.set_args_set_na_sg_grid_dns_servers())
-        my_obj = grid_dns_module()
         mock_request.side_effect = [
+            SRR["version_114"],
             SRR["dns_servers"],  # get
             SRR["end_of_sequence"],
         ]
+        my_obj = grid_dns_module()
         with pytest.raises(AnsibleExitJson) as exc:
             my_obj.apply()
         print("Info: test_idempotent_set_na_sg_grid_dns_servers_pass: %s" % repr(exc.value.args[0]))
@@ -189,12 +196,13 @@ class TestMyModule(unittest.TestCase):
     @patch("ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request")
     def test_add_na_sg_grid_dns_servers_pass(self, mock_request):
         set_module_args(self.set_args_add_na_sg_grid_dns_server())
-        my_obj = grid_dns_module()
         mock_request.side_effect = [
+            SRR["version_114"],
             SRR["dns_servers"],  # get
             SRR["add_dns_servers"],  # post
             SRR["end_of_sequence"],
         ]
+        my_obj = grid_dns_module()
         with pytest.raises(AnsibleExitJson) as exc:
             my_obj.apply()
         print("Info: test_add_na_sg_grid_dns_servers_pass: %s" % repr(exc.value.args[0]))
@@ -203,12 +211,13 @@ class TestMyModule(unittest.TestCase):
     @patch("ansible_collections.netapp.storagegrid.plugins.module_utils.netapp.SGRestAPI.send_request")
     def test_remove_na_sg_grid_dns_servers_pass(self, mock_request):
         set_module_args(self.set_args_remove_na_sg_grid_dns_server())
-        my_obj = grid_dns_module()
         mock_request.side_effect = [
+            SRR["version_114"],
             SRR["dns_servers"],  # get
             SRR["remove_dns_servers"],  # post
             SRR["end_of_sequence"],
         ]
+        my_obj = grid_dns_module()
         with pytest.raises(AnsibleExitJson) as exc:
             my_obj.apply()
         print("Info: test_remove_na_sg_grid_dns_servers_pass: %s" % repr(exc.value.args[0]))
